@@ -113,7 +113,17 @@ class AIHClient:
         response = self.client.put(url=url, data=json.dumps(data), headers=headers)
         
         if response.status_code < 200 or response.status_code >= 300:
-            raise AIHE.AIHClientException(f'PUT request failed: {response.status_code}\n{response.text}')
+            if 'unauthorized' in response.text.lower():
+                # If unauthorized, try to get new toke and try once more
+                self._update_token()
+                url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}' 
+                headers = {"Content-Type": "application/json"}
+                response = self.client.put(url=url, data=json.dumps(data), headers=headers)
+
+                if response.status_code < 200 or response.status_code >= 300:
+                    raise AIHE.AIHClientException(f'PUT request failed: {response.status_code}\n{response.text}')
+            else:
+                raise AIHE.AIHClientException(f'PUT request failed: {response.status_code}\n{response.text}')
         
         
     def _post(self, api:str, endpoint:str, data:dict):
@@ -136,7 +146,17 @@ class AIHClient:
         response = self.client.post(url=url, data=json.dumps(data), headers=headers)
         
         if response.status_code < 200 or response.status_code >= 300:
-            raise AIHE.AIHClientException(f'POST request failed: {response.status_code}\n{response.text}')
+            if 'unauthorized' in response.text.lower():
+                # If unauthorized, try to get new toke and try once more
+                self._update_token()
+                url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}' 
+                headers = {"Content-Type": "application/json"}
+                response = self.client.post(url=url, data=json.dumps(data), headers=headers)
+
+                if response.status_code < 200 or response.status_code >= 300:
+                    raise AIHE.AIHClientException(f'POST request failed: {response.status_code}\n{response.text}')
+            else:
+                raise AIHE.AIHClientException(f'POST request failed: {response.status_code}\n{response.text}')
             
         try:
             return response.json()
@@ -160,7 +180,16 @@ class AIHClient:
         response = self.client.delete(url)
         
         if response.status_code < 200 or response.status_code >= 300:
-            raise AIHE.AIHClientException(f'DELETE request failed: {response.status_code}\n{response.text}')
+            if 'unauthorized' in response.text.lower():
+                # If unauthorized, try to get new toke and try once more
+                self._update_token()
+                url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}/{id}'        
+                response = self.client.delete(url)
+
+                if response.status_code < 200 or response.status_code >= 300:
+                    raise AIHE.AIHClientException(f'DELETE request failed: {response.status_code}\n{response.text}')
+            else:
+                raise AIHE.AIHClientException(f'DELETE request failed: {response.status_code}\n{response.text}')
         
             
     def _download_file(self, file_id:str):
