@@ -404,7 +404,7 @@ class Object:
         return df.groupby(column_group).apply(implode_group)
 
 
-    def join(self, other:Object, self_key:str, other_key:str, keep_dataframe:bool=False, how:str='inner'):
+    def join(self, other, self_key:str, other_key:str, keep_dataframe:bool=False, how:str='inner'):
         """
         join joins two AIH Objects. It matches the 'self_key' from the 'self' object and the 'other_key' on the 'other' object.
         
