@@ -5,7 +5,6 @@ class MediaReference(v1Object):
     
     def __init__(self):
         super().__init__()
-        self._api = 'aih'
         self._endpoint = 'api/v1/media-references'
     
     
@@ -17,10 +16,10 @@ class MediaReference(v1Object):
         """
         
         if id:
-            self.value = self._client.get(self._api, f'{self._endpoint}/{id}')
+            self.value = self._client._get(self._api, f'{self._endpoint}/{id}')
             self.value = self.value['mediaReference']
         else:
-            self.value = self._client.get(self._api, self._endpoint)
+            self.value = self._client._get(self._api, self._endpoint)
             self.value = self.value['mediaReferences']
         
         return self
@@ -32,7 +31,7 @@ class MediaReference(v1Object):
         To post the updates that have been made.
         """
         
-        response_json = self._client.post(self._api, self._endpoint, self.value)
+        response_json = self._client._post(self._api, self._endpoint, self.value)
         self.value['id'] = response_json['mediaReference']['id']
         
         return self
